NodeType

Enum NodeType 

#[non_exhaustive]
pub enum NodeType {
Show 25 variants All, Root, Global, Set, Shader, Attributes, Transform, Instances, Plane, Mesh, FaceSet, Curves, Particles, Nurbs, Procedural, Volume, Environment, OrthographicCamera, PerspectiveCamera, FisheyeCamera, CylindricalCamera, SphericalCamera, OutputDriver, OutputLayer, Screen,
}
Node types in the ɴsɪ scene graph.

Each variant corresponds to a specific node type that can be created in the scene graph.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


All

Wildcard that references all existing nodes at once.



Root

The scene’s root node.



Global

Global settings node.



Set

Expresses relationships of groups of nodes.



Shader

OSL shader or layer in a shader group.



Attributes

Container for generic attributes (e.g. visibility).



Transform

Transformation to place objects in the scene.



Instances

Specifies instances of other nodes.



Plane

An infinite plane.



Mesh

Polygonal mesh or subdivision surface.



FaceSet

Assign attributes to part of a mesh, curves or particles.



Curves

Linear, b-spline and Catmull-Rom curves.



Particles

Collection of particles.



Nurbs

NURBS surface with optional trim curves.



Procedural

Geometry to be loaded or generated in delayed fashion.



Volume

A volume loaded from an OpenVDB file.



Environment

Geometry type to define environment lighting.



OrthographicCamera

An orthographic camera.



PerspectiveCamera

A perspective camera.



FisheyeCamera

A fisheye camera.



CylindricalCamera

A cylindrical camera.



SphericalCamera

A spherical camera.



OutputDriver

A target where to output rendered pixels.



OutputLayer

Describes one render layer to be connected to an output driver.



Screen

Describes how the view from a camera will be rasterized.

Implementations

Source

impl NodeType

pub const fn as_str(&self) -> &'static str

Returns the string identifier used by the C API.

pub fn from_name(s: &str) -> Option<NodeType>

Parse a node type from its string identifier.