Handle

Struct Handle 

pub struct Handle(/* private fields */);
Available on crate feature ustr_handles only.
A node handle string backed by an interned Ustr.

This provides O(1) equality checks and zero-cost conversion to C strings.

Implementations

Source

impl Handle

pub fn new(s: &str) -> Self

Create a new handle from a string slice.

pub fn as_str(&self) -> &str

Get the handle as a string slice.

pub fn as_char_ptr(&self) -> *const c_char

Get the handle as a C string pointer.

The returned pointer is valid for the lifetime of the Ustr cache (effectively ’static for interned strings).